@@ -25,6 +25,7 @@ class AdvancedWorker(Worker):
         """
         Lowering max_poll_interval_ms from 300s to 60s to be more responsive
         to rebalance error, reduce the impact of user timeouts
+        Keep default auto_commit (5000ms) but list here for further tuning
         """
         super().__init__(
             kafka_broker_addr=kafka_opts.get("broker"),
@@ -33,7 +34,10 @@ class AdvancedWorker(Worker):
             create_consumer=False if testing else True,
             create_producer=False if testing else True,
             sasl_opts=kafka_opts.get("sasl_opts"),
-            consumer_opts={"max_poll_interval_ms": 60000},
+            consumer_opts={
+                "max_poll_interval_ms": 60000,
+                "auto_commit_interval_ms": 5000,
+            },
         )
         self._testing = testing
         self._audio_path = tempfile.mkdtemp()
@@ -93,12 +97,12 @@ class AdvancedWorker(Worker):
         await self.create_redis()
         await super().start()
 
-    async def stop(self):
+    async def clean_up_after_run(self):
         """
         Add additional stop logic for redis
         """
-        await self.destroy_redis()  # destroy redis before others
-        await super().stop()
+        await super().clean_up_after_run()
+        await self.destroy_redis()
 
     @staticmethod
     def get_worker_version():
@@ -106,9 +110,14 @@ class AdvancedWorker(Worker):
         Parses worker metadada and returns it
         :return:
         """
-        with open("metadata.json", "r") as f:
-            data = f.read()
-            metadata = json.loads(data)
+        metadata = None
+        try:
+            with open("metadata.json", "r") as f:
+                data = f.read()
+                metadata = json.loads(data)
+        except Exception:
+            logger.error("metadata does not exist")
+
         return metadata
 
     @staticmethod
