@@ -28,7 +28,7 @@ class Daemon:
             self._worker = Worker(**kwargs)
 
     async def run(self):
-        loop = asyncio.get_event_loop()
+        loop = asyncio.get_running_loop()
         logger = logging.getLogger("Daemon")
         logger.debug("Starting AIOKafkaDaemon")
         for signame in ("SIGINT", "SIGTERM"):
