@@ -161,6 +161,10 @@ class Worker:
         logger.warning("System stopping, stopping consumer first")
         await self.stop_kafka(False)
 
+    async def clean_up_after_run(self):
+        logger.warning("clean up after run")
+        await self.stop_kafka(True)
+
     async def run(self):
         """
         Main method for the worker. Any child class can either
@@ -185,9 +189,7 @@ class Worker:
                 "{}:\n{}".format(exc, traceback.format_exc())
             )
         finally:
-            # it's to better to stop kafka components, better
-            # than keep it running with problems.
-            await self.stop_kafka()
+            await self.clean_up_after_run()
 
     async def send_heartbeat(self, step_functions_task_id):
         """
